@@ -51,19 +51,18 @@ sub fret
     my (%opt);
     my ($fh, $fdat);
 
-    getopts("d:fgh:m:p:qrs:", \%opt);
+    getopts("fgh:m:p:qs:", \%opt);
 
     unless (defined $ARGV[0])
     {
         die <<'EOT';
-FRET [-f] [-g] [-r] [-s size] [-p package] [-q] font_file [out_file]
+FRET [-f] [-g] [-s size] [-p package] [-q] font_file [out_file]
 Generates a report on a font according to a particular package. In some
 contexts the package may be over-ridden. Paper size may also be specified.
 
 If no out_file is given then out_file becomes font_file.pdf (removing .ttf
 if present)
 
-  -d num        Sets time for testing purposes
   -f            Don't try to save memory on large fonts (>1000 glyphs)
   -g            Add one glyph per page report following summary report
   -h            Mode for glyph per page output. Bitfield:
@@ -71,8 +70,7 @@ if present)
   -m points     Sets glyph size in the box regardless of what is calculated
                 Regardless of the consequences for clashes
   -p package    Perl package specification to use for report information
-  -q            quiet mode
-  -r            Don't output report lines, fill the page with glyph boxes
+  -q            quiet mode  
   -s size       paper size: a4, ltr, legal
 EOT
     }
@@ -151,7 +149,6 @@ sub process_font
     my ($gcount, $tr, $tr1, $ppage, @time, @boxhdr, @boxloc, @cids, $numc, $gid);
     my ($type, $rpos);
     my ($optgsize, $maxp);
-    my ($numperow) = $opt{'r'} ? 10 : 4;
 
 #    $font->tables_do(sub { $_[0]->read; });
     @rev = $font->{'cmap'}->read->reverse;
@@ -189,8 +186,8 @@ sub process_font
 #    print "numg = $numg\n";
     ($type, @cids) = $package->make_cids($font);
     $numc = @cids;
-    $maxg = int(($maxy - 121) / 67) * $numperow;
-    $nump = int(($numc + $maxg - 1) / $maxg);
+    $maxg = (($maxy - 121) / 67) << 2;
+    $nump = int (($numc + $maxg - 1) / $maxg);
 #    print "maxg = $maxg\nnump = $nump\n";
     $maxp = $nump;
     $maxp += $numc if ($opt{g});
@@ -209,7 +206,7 @@ no strict;
     $ftrleft = "BT 1 0 0 1 36 27 Tm 80 Tz /FR 7 Tf (FRET v$VERSION "
         . "Package $package " . ${"${package}::VERSION"} . ") Tj ET\n";
 use strict;
-    @time = split(/\s+/, localtime($opt{d} || time()));
+    @time = split(/\s+/, localtime());
     $tr = "Printed at $time[3] on $time[0] $time[2] $time[1] $time[4]   Page ";
     @time = split(/\s+/, localtime($font->{'head'}->getdate));
     $hdrrw = "Modified at $time[3] on $time[0] $time[2] $time[1] $time[4]";
@@ -226,7 +223,7 @@ use strict;
         " l s [] 0 d ".
         "BT 1 0 0 1 39 " . ($maxy - 81) . " Tm 80 Tz /FI 9 Tf (Size: ) Tj /FB 9 Tf ($tsize pt   ) Tj ".
         "/FI 9 Tf (Em: ) Tj /FB 9 Tf ($upem   ) Tj /FI 9 Tf ".
-        "(Type: ) Tj /FB 9 Tf ($type) Tj 225 3 Td /FR 8 Tf (" . ($opt{'r'} ? '' : 'Glyph') . ") Tj ET\n";
+        "(Type: ) Tj /FB 9 Tf ($type) Tj 225 3 Td /FR 8 Tf (Glyph) Tj ET\n";
     @boxhdr = $package->boxhdr($font);
     @boxloc = ([199, 85], [251, 85], [199, 77], [251, 77]);
     for ($i = 0; $i < 4; $i++)
@@ -267,23 +264,17 @@ use strict;
         @row2 = ($row2[0]);
 
         $ybase = $maxy - 153;
-        for ($row = 0; $row < $maxg / $numperow; $row++)
+        for ($row = 0; $row < $maxg / 4; $row++)
         {
-            $ppage->add(".5 w 36 $ybase " . ($numperow * 54) . " 64 re S ");
-            for ($i = 0; $i < $numperow - 1; $i++)
-            {
-                my ($x) = 90 + $i * 54;
-                $ppage->add("$x $ybase m $x " . ($ybase + 64) . " l S ");
-            }
-            unless ($opt{'r'})
-            {
-                $ppage->add(" $dots 264 " . ($ybase + 65.5) . " m " . ($maxx - 36) . " "
+            $ppage->add(".5 w 36 $ybase 216 64 re S 90 $ybase m 90 " . ($ybase + 64)
+                   . " l S 144 $ybase m 144 " . ($ybase + 64) . " l S"
+                   . " 198 $ybase m 198 " . ($ybase + 64) . " l S"
+                   . " $dots 264 " . ($ybase + 65.5) . " m " . ($maxx - 36) . " "
                    . ($ybase + 65.5) . " l s [] 0 d\n");
-            }
             $yorg = $ybase + 32 - ($font->{'head'}{'yMax'} + $font->{'head'}{'yMin'}) * $tsize / $upem / 2;
-            $ppage->add("$dots 36 $yorg m " . (36 + $numperow * 54) . " $yorg l S [] 0 d\n") if ($yorg > $ybase);
+            $ppage->add("$dots 36 $yorg m 252 $yorg l S [] 0 d\n") if ($yorg > $ybase);
             $xcentre = 63;
-            for ($i = 0; $i < $numperow; $i++, $xcentre += 54)
+            for ($i = 0; $i < 4; $i++, $xcentre += 54)
             {
                 next if ($gcount + $i >= $numc);
                 $gcol = "";
@@ -298,17 +289,20 @@ use strict;
                     $xorg = ($glyph->{'xMax'} + $glyph->{'xMin'}) * $tsize / $upem;
                     $xorg = $xcentre - $xorg / 2;
                     $xadv = $xorg + $font->{'hmtx'}{'advance'}[$gid] * $tsize / $upem;
-                    $ppage->add(sprintf("%s %.4f %d m %.4f %d l S [] 0 d\n", $dots, $xadv, $ybase + 7, $xadv,$ybase + 57)) if ($xadv < $xcentre + 27);
-                    $ppage->add(sprintf("%s %.4f %d m %.4f %d l S [] 0 d\n", $dots, $xorg, $ybase + 7, $xorg, $ybase + 57)) if ($xorg > $xcentre - 27 && $xorg < $xcentre + 27);
-                    $ppage->add(sprintf("BT 1 0 0 1 %.4f %.4f Tm /T$id $tsize Tf 100 Tz $gcol <%04X> Tj %s ET\n", $xorg, $yorg, $gid, ($gcol ? "0 g " : "")));
-                    unless ($opt{'r'})
-                    {
-                        $gxorg = ($glyph->{'xMax'} + $glyph->{'xMin'}) * $gsize / $upem / 2;
-                        $gxorg = 274 - $gxorg;
-                        $gyorg = $ybase + (3 - $i) * 16 + 8 - ($font->{'head'}{'yMax'} +
-                                $font->{'head'}{'yMin'}) * $gsize / $upem / 2;;
-                        $ppage->add(sprintf("BT 1 0 0 1 %.4f %.4f Tm /T$id $gsize Tf 100 Tz <%04X> Tj ET\n", $gxorg, $gyorg, $gid));
-                    }
+                    $ppage->add("$dots $xadv " . ($ybase + 7) . " m $xadv "
+                            . ($ybase + 57) . " l S [] 0 d\n") if ($xadv < $xcentre + 27);
+                    $ppage->add("$dots $xorg " . ($ybase + 7) . " m $xorg "
+                            . ($ybase + 57) . " l S [] 0 d\n") if ($xorg > $xcentre - 27
+                            && $xorg < $xcentre + 27);
+                    $ppage->add("BT 1 0 0 1 $xorg $yorg Tm /T$id $tsize Tf 100 Tz " .
+                            $gcol . sprintf("<%04X> Tj " .
+                            ($gcol ? "0 g " : "") . "ET\n", $gid));
+                    $gxorg = ($glyph->{'xMax'} + $glyph->{'xMin'}) * $gsize / $upem / 2;
+                    $gxorg = 274 - $gxorg;
+                    $gyorg = $ybase + (3 - $i) * 16 + 8 - ($font->{'head'}{'yMax'} +
+                            $font->{'head'}{'yMin'}) * $gsize / $upem / 2;;
+                    $ppage->add("BT 1 0 0 1 $gxorg $gyorg Tm /T$id $gsize Tf 100 Tz " .
+                            sprintf("<%04X> Tj ET\n", $gid));
                 }
                 @parms = ($cids[$gcount + $i], $gid, $glyph, $rev[$gid], $font);
                 @rowt = $package->topdat(@parms);
@@ -321,31 +315,25 @@ use strict;
                 @xorg = ([$xcentre - 26, $xcentre + 24 - $roww[1]],
                         [$xcentre + 25 - $roww[1], $xcentre + 26]);
                 $ppage->add(out_row($pdf, 6, $ybase + 2, \@xorg, \@rowt));
-                unless ($opt{'r'})
-                {
-                    @rowt = $package->row1(@parms);
-                    @roww = widths(8, \@rowt);
-                    push (@row1, [[@rowt], [@roww], $ybase + (3-$i) * 16 + 8.75, 8]);
-                    @rowt = $package->row2(@parms);
-                    @roww = widths(8, \@rowt);
-                    push (@row2, [[@rowt], [@roww], $ybase + (3-$i) * 16 + .75, 8]);
-                    $glyph->empty if ($glyph && $numg > 1000 && !$opt{f});
-                }
+                @rowt = $package->row1(@parms);
+                @roww = widths(8, \@rowt);
+                push (@row1, [[@rowt], [@roww], $ybase + (3-$i) * 16 + 8.75, 8]);
+                @rowt = $package->row2(@parms);
+                @roww = widths(8, \@rowt);
+                push (@row2, [[@rowt], [@roww], $ybase + (3-$i) * 16 + .75, 8]);
+                $glyph->empty if ($glyph && $numg > 1000 && !$opt{f});
             }
-            $gcount += $numperow;
-            last if ($gcount >= $numc);
-            $ybase -= 67;
+        $gcount += 4;
+        last if ($gcount >= $numc);
+        $ybase -= 67;
         }
-        unless ($opt{'r'})
-        {
-            @rowm = maxwidth(\@row1, $maxx - 330);
-            putrows($pdf, \@row1, \@rowm, 294, $ppage);
-            @rowm = maxwidth(\@row2, $maxx - 348);
-            putrows($pdf, \@row2, \@rowm, 312, $ppage);
-        }
-        $ppage->{' curstrm'}{'Filter'} = PDFArray(PDFName('FlateDecode'));
-        $ppage->ship_out($pdf);
-        $ppage->empty;
+    @rowm = maxwidth(\@row1, $maxx - 330);
+    putrows($pdf, \@row1, \@rowm, 294, $ppage);
+    @rowm = maxwidth(\@row2, $maxx - 348);
+    putrows($pdf, \@row2, \@rowm, 312, $ppage);
+    $ppage->{' curstrm'}{'Filter'} = PDFArray(PDFName('FlateDecode'));
+    $ppage->ship_out($pdf);
+    $ppage->empty;
     }
 
     return unless $opt{g};
@@ -630,11 +618,11 @@ sub out_row
                 if $info[2] =~ m/([0-9a-f]{2})([0-9a-f]{2})([0-9a-f]{2})/oi;
         $f = "BT $col 1 0 0 1 ";
         if ($info[0] =~ m/r/oi)
-        { $f .= sprintf("%.4f", $xr); }
+        { $f .= "$xr"; }
         elsif ($info[0] =~ m/c/oi)
-        { $f .= sprintf("%.4f", $xc); }
+        { $f .= "$xc"; }
         else
-        { $f .= sprintf("%.4f", $xl); }
+        { $f .= "$xl"; }
         $f .= " $yorg Tm ";
         $g = PDFStr($e);
         $f .= "/F$ft $pt Tf 80 Tz " . $g->as_pdf . " Tj ET";
@@ -747,8 +735,6 @@ C<\|> (notice that there is no need to escape C<\> or any other character).
 The formatting is structured as a comma separated list of 3 elements: justification,
 font styling and then colour.
 
-=over 8
-
 =item justification
 
 The values are r: right justified; c: centred and the default of l: left justified
